"""
oedix — Minimal Core + Plugin Agent Framework

Usage::

    import oedix

    agent = oedix.Agent(config="agent.json", data_dir="/data")
    agent.set_event_handler(my_handler)

    async for event in agent.run("안녕하세요"):
        ...

Lower-level imports::

    from oedix.core import AgentQueue, ActionSet, Action, Context
    from oedix.core.config import AgentConfig
    from oedix.core.events import Event, EventType
"""

__version__ = "0.0.1"

from oedix.agent import Agent

__all__ = ["Agent"]
